nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Pmc

Struct Pmc 

pub struct Pmc { /* private fields */ }
PMC

Implementations

Source

impl Pmc

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn status(self) -> Reg<Status, R>

Power Management Controller FSM (Finite State Machines) status

pub const fn resetctrl(self) -> Reg<Resetctrl, RW>

Reset Control [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn dcdc0(self) -> Reg<Dcdc0, RW>

DCDC (first) control register [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn dcdc1(self) -> Reg<Dcdc1, RW>

DCDC (second) control register [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn ldopmu(self) -> Reg<Ldopmu, RW>

Power Management Unit (PMU) and Always-On domains LDO control [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn bodvbat(self) -> Reg<Bodvbat, RW>

VBAT Brown Out Dectector (BoD) control register [Reset by: PoR, Pin Reset, Software Reset]

pub const fn reffastwkup(self) -> Reg<Reffastwkup, RW>

Analog References fast wake-up Control register [Reset by: PoR]

pub const fn xtal32k(self) -> Reg<Xtal32k, RW>

32 KHz Crystal oscillator (XTAL) control register [Reset by: PoR, Brown Out Detectors Reset]

pub const fn comp(self) -> Reg<Comp, RW>

Analog Comparator control register [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn wakeupioctrl(self) -> Reg<Wakeupioctrl, RW>

Deep Power Down wake-up source [Reset by: PoR, Pin Reset, Software Reset]

pub const fn wakeiocause(self) -> Reg<Wakeiocause, RW>

Allows to identify the Wake-up I/O source from Deep Power Down mode

pub const fn statusclk(self) -> Reg<Statusclk, RW>

FRO and XTAL status register [Reset by: PoR, Brown Out Detectors Reset]

pub const fn aoreg1(self) -> Reg<Aoreg1, RW>

General purpose always on domain data storage [Reset by: PoR, Brown Out Detectors Reset]

pub const fn miscctrl(self) -> Reg<Miscctrl, RW>

Dummy Control bus to PMU [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn rtcosc32k(self) -> Reg<Rtcosc32k, RW>

RTC 1 KHZ and 1 Hz clocks source control register [Reset by: PoR, Brown Out Detectors Reset]

pub const fn ostimer(self) -> Reg<Ostimer, RW>

OS Timer control register [Reset by: PoR, Brown Out Detectors Reset]

pub const fn pdruncfg0(self) -> Reg<Pdruncfg0, RW>

Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn pdruncfgset0(self) -> Reg<Pdruncfgset0, W>

Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn pdruncfgclr0(self) -> Reg<Pdruncfgclr0, W>

Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

pub const fn sramctrl(self) -> Reg<Sramctrl, RW>

All SRAMs common control signals [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Software Reset]